@@ -1946,6 +1946,9 @@ void dd_QuickSort(dd_rowindex OV, long p, long r, dd_Amatrix A, long dmax)
 #ifndef RAND_MAX 
 #define RAND_MAX 32767 
 #endif
+#ifndef R_HAS_JUMPED_THE_SHARK
+#include "my_unif_rand.h"
+#endif /* R_HAS_JUMPED_THE_SHARK */
 
 void dd_RandomPermutation(dd_rowindex OV, long t, unsigned int seed)
 {
@@ -1953,10 +1956,16 @@ void dd_RandomPermutation(dd_rowindex OV, long t, unsigned int seed)
   double u,xk,r,rand_max=(double) RAND_MAX;
   dd_boolean localdebug=dd_FALSE;
 
+#ifdef R_HAS_JUMPED_THE_SHARK
   srand(seed);
+#endif /* R_HAS_JUMPED_THE_SHARK */
   for (j=t; j>1 ; j--) {
+#ifdef R_HAS_JUMPED_THE_SHARK
     r=rand();
     u=r/rand_max;
+#else /* R_HAS_JUMPED_THE_SHARK */
+    u = my_unif_rand();
+#endif /* R_HAS_JUMPED_THE_SHARK */
     xk=(double)(j*u +1);
     k=(long)xk;
 #ifdef R_HAS_JUMPED_THE_SHARK
