@@ -21,6 +21,7 @@
 
 #include "setoper.h"
 #include "cdd.h"
+#include <R.h>
 #include <Rinternals.h>
 #include "mycddio_f.h"
 #include <string.h>
@@ -31,6 +32,7 @@
 
 SEXP lpcdd_f(SEXP hrep, SEXP objfun, SEXP minimize, SEXP solver)
 {
+    GetRNGstate();
     if (! isMatrix(hrep))
         error("'hrep' must be matrix");
     if (! isReal(hrep))
@@ -426,6 +428,7 @@ SEXP lpcdd_f(SEXP hrep, SEXP objfun, SEXP minimize, SEXP solver)
     ddf_free_global_constants();
 
     UNPROTECT(1);
+    PutRNGstate();
     return result;
 }
 
